@@ -1,14 +1,14 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, TypeAlias, Union
 
 import vapoursynth as vs
 
 from ..exceptions import (
     UndefinedChromaLocationError, UndefinedFieldBasedError, UnsupportedChromaLocationError, UnsupportedFieldBasedError
 )
-from ..types import MISSING, FuncExceptT
-from .stubs import _ChromaLocationMeta, _FieldBasedMeta
+from ..types import FuncExceptT
+from .stubs import _base_from_video, _ChromaLocationMeta, _FieldBasedMeta
 
 __all__ = [
     'ChromaLocation', 'ChromaLocationT',
@@ -39,10 +39,6 @@ class ChromaLocation(_ChromaLocationMeta):
     BOTTOM_LEFT = 4
     BOTTOM = 5
 
-    @property
-    def is_unknown(self) -> bool:
-        return False
-
     @classmethod
     def from_res(cls, frame: vs.VideoNode | vs.VideoFrame) -> ChromaLocation:
         from ..utils import get_var_infos
@@ -55,21 +51,10 @@ class ChromaLocation(_ChromaLocationMeta):
         return ChromaLocation.LEFT
 
     @classmethod
-    def from_video(cls, src: vs.VideoNode | vs.VideoFrame | vs.FrameProps, strict: bool = False) -> ChromaLocation:
-        from ..utils import get_prop
-
-        value = get_prop(src, '_ChromaLocation', int, default=MISSING if strict else None)
-
-        if value is None:
-            if strict:
-                raise UndefinedChromaLocationError(f'ChromaLocation({value}) is undefined.', cls.from_video)
-
-            if isinstance(src, vs.FrameProps):
-                raise UndefinedChromaLocationError('Can\'t determine chroma location from FrameProps.', cls.from_video)
-
-            return cls.from_res(src)
-
-        return cls(value)
+    def from_video(
+        cls, src: vs.VideoNode | vs.VideoFrame | vs.FrameProps, strict: bool = False, func: FuncExceptT | None = None
+    ) -> ChromaLocation:
+        return _base_from_video(cls, src, UndefinedChromaLocationError, strict, func)
 
 
 class FieldBased(_FieldBasedMeta):
@@ -79,6 +64,8 @@ class FieldBased(_FieldBasedMeta):
 
     @classmethod
     def _missing_(cls: type[FieldBased], value: Any) -> FieldBased | None:
+        value = super()._missing_(value)
+
         if value is None:
             return cls.PROGRESSIVE
 
@@ -91,10 +78,6 @@ class FieldBased(_FieldBasedMeta):
     BFF = 1
     TFF = 2
 
-    @property
-    def is_unknown(self) -> bool:
-        return False
-
     if not TYPE_CHECKING:
         @classmethod
         def from_param(cls: Any, value_or_tff: Any, func_except: Any = None) -> FieldBased | None:
@@ -104,21 +87,10 @@ class FieldBased(_FieldBasedMeta):
             return super().from_param(value_or_tff)
 
     @classmethod
-    def from_video(cls, src: vs.VideoNode | vs.VideoFrame | vs.FrameProps, strict: bool = False) -> FieldBased:
-        from ..utils import get_prop
-
-        value = get_prop(src, '_FieldBased', int, default=MISSING if strict else None)
-
-        if value is None:
-            if strict:
-                raise UndefinedFieldBasedError(f'FieldBased({value}) is undefined.', cls.from_video)
-
-            if isinstance(src, vs.FrameProps):
-                raise UndefinedFieldBasedError('Can\'t determine field type from FrameProps.', cls.from_video)
-
-            return FieldBased.PROGRESSIVE
-
-        return cls(value)
+    def from_video(
+        cls, src: vs.VideoNode | vs.VideoFrame | vs.FrameProps, strict: bool = False, func: FuncExceptT | None = None
+    ) -> FieldBased:
+        return _base_from_video(cls, src, UndefinedFieldBasedError, strict, func)
 
     @property
     def is_inter(self) -> bool:
@@ -138,16 +110,6 @@ class FieldBased(_FieldBasedMeta):
     def is_tff(self) -> bool:
         return self is self.TFF
 
-    @classmethod
-    def ensure_presence(
-        cls, clip: vs.VideoNode,
-        tff: bool | int | FieldBased | None,
-        func: FuncExceptT | None = None
-    ) -> vs.VideoNode:
-        value = FieldBased.from_param(tff, func) or FieldBased.from_video(clip, True)
 
-        return clip.std.SetFieldBased(value.field)
-
-
-ChromaLocationT = int | vs.ChromaLocation | ChromaLocation
-FieldBasedT = int | vs.FieldBased | FieldBased
+ChromaLocationT: TypeAlias = Union[int, vs.ChromaLocation, ChromaLocation]
+FieldBasedT: TypeAlias = Union[int, vs.FieldBased, FieldBased]
